<?php
/**
 * Plugin Name: BeepMate - Forms to your messaging app
 * Plugin URI: https://beepmate.io/wordpress-to-whatsapp
 * Description: Redirect WordPress form submissions to WhatsApp
 * Version: 1.1.2
 * Author: Adam Ben-Gur
 * Author URI: https://beepmate.io
 * Text Domain: beepmate
 * License: GPL-2.0+
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Requires at least: 5.0
 * Requires PHP: 7.0
 * Tested up to: 6.7.2
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}


// Sanitize settings
function beepmate_whatsapp_forms_sanitize_settings($input) {
    $sanitized = array();
    
    if (isset($input['beepmate_api_key'])) {
        $sanitized['beepmate_api_key'] = sanitize_text_field($input['beepmate_api_key']);
    }
    
    if (isset($input['whatsapp_recipient_id'])) {
        $sanitized['whatsapp_recipient_id'] = sanitize_text_field($input['whatsapp_recipient_id']);
    }
    
    if (isset($input['redirect_all_forms'])) {
        $sanitized['redirect_all_forms'] = ($input['redirect_all_forms'] === 'yes') ? 'yes' : 'no';
    }
    
    if (isset($input['api_method'])) {
        $valid_methods = array('curl', 'file_get_contents', 'exec');
        $sanitized['api_method'] = in_array($input['api_method'], $valid_methods) ? $input['api_method'] : 'curl';
    }
    
    if (isset($input['debug_mode'])) {
        $sanitized['debug_mode'] = ($input['debug_mode'] === 'yes') ? 'yes' : 'no';
    }
    
    return $sanitized;
}
add_filter('pre_update_option_beepmate_whatsapp_forms_settings', 'beepmate_whatsapp_forms_sanitize_settings');

/**
 * Plugin activation hook
 */
function beepmate_whatsapp_forms_activate() {
    // Add default settings
    $default_options = beepmate_whatsapp_forms_get_defaults();
    
    if (!get_option('beepmate_whatsapp_forms_settings')) {
        add_option('beepmate_whatsapp_forms_settings', $default_options);
    }
}
register_activation_hook(__FILE__, 'beepmate_whatsapp_forms_activate');
// Define default settings
function beepmate_whatsapp_forms_get_defaults() {
    return array(
        'beepmate_api_key' => '',
        'whatsapp_recipient_id' => '',
        'redirect_all_forms' => 'yes',
        'api_method' => 'wp_remote',
        'debug_mode' => 'no'
    );
}

/**
 * Plugin deactivation hook
 */
function beepmate_whatsapp_forms_deactivate() {
    // No cleanup needed
}
register_deactivation_hook(__FILE__, 'beepmate_whatsapp_forms_deactivate');

/**
 * Register the admin menu
 */
function beepmate_whatsapp_forms_admin_menu() {
    add_options_page(
        __('BeepMate', 'beepmate'),
        __('BeepMate', 'beepmate'),
        'manage_options',
        'beepmate',
        'beepmate_whatsapp_forms_settings_page'
    );
}
add_action('admin_menu', 'beepmate_whatsapp_forms_admin_menu');

/**
 * Register settings
 */
function beepmate_whatsapp_forms_register_settings() {

    register_setting(
        'beepmate_whatsapp_forms_settings_group',  // Option group
        'beepmate_whatsapp_forms_settings',        // Option name
        'beepmate_whatsapp_forms_sanitize_settings' // Sanitization callback
    );
}
add_action('admin_init', 'beepmate_whatsapp_forms_register_settings');


// Then when you get options, merge with defaults:
function beepmate_whatsapp_forms_get_options() {
    $defaults = beepmate_whatsapp_forms_get_defaults();
    $options = get_option('beepmate_whatsapp_forms_settings', array());
    return wp_parse_args($options, $defaults);
}

function beepmate_whatsapp_forms_update_check() {
    $current_version = get_option('beepmate_whatsapp_forms_version', '0');
    
    // If this is an older version that needs update
    if (version_compare($current_version, '1.1.0', '<')) {
        $options = get_option('beepmate_whatsapp_forms_settings', array());
        
        // Set redirect_all_forms to 'yes' if not explicitly set to something else
        if (!isset($options['redirect_all_forms'])) {
            $options['redirect_all_forms'] = 'yes';
            update_option('beepmate_whatsapp_forms_settings', $options);
        }
        
        // Update the version
        update_option('beepmate_whatsapp_forms_version', '1.1.0');
    }
}
add_action('admin_init', 'beepmate_whatsapp_forms_update_check');


/**
 * Make API call using WordPress HTTP API
 */
function beepmate_whatsapp_forms_wp_remote_call($api_url) {
    // Log the URL (without API key)
    $log_url = preg_replace('/key=([^&]+)/', 'key=HIDDEN', $api_url);
    beepmate_whatsapp_forms_debug('WordPress HTTP API URL: ' . $log_url);
    
    // Make the API call
    $response = wp_remote_get($api_url, array(
        'timeout' => 30,
        'sslverify' => false,
    ));
    
    // Check for errors
    if (is_wp_error($response)) {
        beepmate_whatsapp_forms_debug('WordPress HTTP API Error: ' . $response->get_error_message());
        return 'API request error: ' . $response->get_error_message();
    }
    
    // Get response code and body
    $http_code = wp_remote_retrieve_response_code($response);
    $body = wp_remote_retrieve_body($response);
    
    // Log the response
    beepmate_whatsapp_forms_debug('WordPress HTTP API Response Code: ' . $http_code);
    beepmate_whatsapp_forms_debug('WordPress HTTP API Response: ' . $body);
    
    // Check response
    if ($http_code == 200) {
        return true;
    } else {
        return 'HTTP error: ' . $http_code;
    }
}
/**
 * Make API POST call with file attachments using WordPress HTTP API
 */
function beepmate_whatsapp_forms_wp_remote_post_with_file($api_url, $api_key, $recipient_id, $message, $file_path) {
    // Prepare the post data with file
    $file_name = basename($file_path);
    $file_type = wp_check_filetype($file_name)['type'];
    $file_content = file_get_contents($file_path);
    
    $boundary = wp_generate_password(24, false);
    
    $payload = '';
    // Add key field
    $payload .= '--' . $boundary . "\r\n";
    $payload .= 'Content-Disposition: form-data; name="key"' . "\r\n\r\n";
    $payload .= $api_key . "\r\n";
    
    // Add ID field
    $payload .= '--' . $boundary . "\r\n";
    $payload .= 'Content-Disposition: form-data; name="id"' . "\r\n\r\n";
    $payload .= $recipient_id . "\r\n";
    
    // Add message field
    if (!empty($message)) {
        $payload .= '--' . $boundary . "\r\n";
        $payload .= 'Content-Disposition: form-data; name="msg"' . "\r\n";
        $payload .= 'Content-Type: text/plain; charset=UTF-8' . "\r\n\r\n";
        $payload .= $message . "\r\n";
    }
    
    // Add file field
    $payload .= '--' . $boundary . "\r\n";
    $payload .= 'Content-Disposition: form-data; name="file"; filename="' . $file_name . '"' . "\r\n";
    $payload .= 'Content-Type: ' . $file_type . "\r\n\r\n";
    $payload .= $file_content . "\r\n";
    $payload .= '--' . $boundary . '--';
    
    // Make the request
    $response = wp_remote_post($api_url, array(
        'timeout' => 60,
        'headers' => array(
            'Content-Type' => 'multipart/form-data; boundary=' . $boundary,
        ),
        'body' => $payload,
        'sslverify' => false,
    ));
    
    // Check for errors and return result (same as the GET function)
    if (is_wp_error($response)) {
        return 'API request error: ' . $response->get_error_message();
    }
    
    $http_code = wp_remote_retrieve_response_code($response);
    if ($http_code == 200) {
        return true;
    } else {
        return 'HTTP error: ' . $http_code;
    }
}
/**
 * Custom debug function
 */
function beepmate_whatsapp_forms_debug($message) {
    $options = get_option('beepmate_whatsapp_forms_settings');
    $debug_enabled = $options['debug_mode'] ?? 'no';
    
    if ($debug_enabled === 'yes' || defined('WP_DEBUG') && WP_DEBUG) {
        if (is_array($message) || is_object($message)) {
            error_log('BeepMate Debug: ' . print_r($message, true));
        } else {
            error_log('BeepMate Debug: ' . $message);
        }
    }
}

/**
 * Settings page HTML
 */
function beepmate_whatsapp_forms_settings_page() {
    $options = get_option('beepmate_whatsapp_forms_settings');
    ?>

    <div class="wrap">
        <h1><span style="color:#C5221F">BEEP</span><span style="color:#25D366">MATE</span> - Forms to WhatsApp</h1>
        <p>Automatically send WordPress form submissions to WhatsApp instead of or alongside emails. </p>
        <p>Visit <a href="https://beepmate.io" target="_blank">https://beepmate.io</a> to create an account and obtain your API key.</p>
        <form method="post" action="options.php">
            <?php 
                settings_fields('beepmate_whatsapp_forms_settings_group'); 
                wp_nonce_field('beepmate_whatsapp_forms_settings_nonce', 'beepmate_whatsapp_forms_settings_nonce');
            ?>
            
            
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="beepmate_api_key">BeepMate API Key</label>
                    </th>
                    <td>
                        <input type="text" id="beepmate_api_key" name="beepmate_whatsapp_forms_settings[beepmate_api_key]" 
                               value="<?php echo esc_attr($options['beepmate_api_key'] ?? ''); ?>" class="regular-text">
                    </td>
                </tr>
                
                <tr>
                    <th scope="row">
                        <label for="whatsapp_recipient_id">WhatsApp User ID</label>
                    </th>
                    <td>
                        <input type="text" id="whatsapp_recipient_id" name="beepmate_whatsapp_forms_settings[whatsapp_recipient_id]" 
                               value="<?php echo esc_attr($options['whatsapp_recipient_id'] ?? ''); ?>" class="regular-text">
                    </td>
                </tr>
                
                
                <tr>
                    <th scope="row">API Method</th>
                    <td>
                        <select name="beepmate_whatsapp_forms_settings[api_method]">
                            <option value="wp_remote" <?php selected('wp_remote', $options['api_method'] ?? 'wp_remote'); ?>>WordPress HTTP API (Recommended)</option>
                            <option value="curl" <?php selected('curl', $options['api_method'] ?? 'curl'); ?>>cURL (Recommended)</option>
                            <option value="file_get_contents" <?php selected('file_get_contents', $options['api_method'] ?? 'curl'); ?>>file_get_contents</option>
                            <option value="exec" <?php selected('exec', $options['api_method'] ?? 'curl'); ?>>exec (System Command)</option>
                        </select>
                        <p class="description">Select the method to use for API calls. Try a different one if messages aren't being delivered.</p>
                    </td>
                </tr>

                <tr>
                    <th scope="row">Submit forms to WhatsApp</th>
                    <td>
                        <label>
                            <input type="checkbox" name="beepmate_whatsapp_forms_settings[redirect_all_forms]" value="yes" 
                                <?php checked('yes', $options['redirect_all_forms'] ?? 'no'); ?>>
                            Enable plugin
                        </label>      
                        <p class="description">Disable this to temporarily deactivate the plugin.</p>                  
                        
                    </td>
                </tr>

                <tr>
                    <th scope="row">Debug Mode</th>
                    <td>
                        <label>
                            <input type="checkbox" name="beepmate_whatsapp_forms_settings[debug_mode]" value="yes" 
                                <?php checked('yes', $options['debug_mode'] ?? 'no'); ?>>
                            Enable debug logging
                        </label>
                        <p class="description">Enable this to log detailed debugging information. </p>
                    </td>
                </tr>
            </table>
            
            <?php submit_button(); ?>
        </form>

        <div style="margin-top: 30px; background-color: #f8f9fa; padding: 15px; border: 1px solid #ddd;">
            <div style="margin-top: 30px;">
                <h2>Test Your Configuration</h2>
                <p>Send a test message to confirm your WhatsApp integration is working:</p>
                
                <form method="post" action="">
                    <?php wp_nonce_field('beepmate_whatsapp_forms_test', 'beepmate_whatsapp_forms_test_nonce'); ?>
                    <table class="form-table"  style="display: none;">
                        <tr>
                            <th scope="row">
                                <label for="test_message">Test Message</label>
                            </th>
                            <td>
                                <input type="text" id="test_message" name="test_message" value="This is a test message from BeepMate WhatsApp Forms plugin." class="regular-text">
                            </td>
                        </tr>
                    </table>
                    
                    <input type="hidden" name="action" value="send_test_message">
                    <?php submit_button('Send Test Message', 'secondary'); ?>
                </form>
            </div>
        </div>
        
        <div style="margin-top: 30px; background-color: #f8f9fa; padding: 15px; border: 1px solid #ddd;">
            <h2>Limits</h2>
            <p>BeepMate has a <strong>FREE FOREVER</strong> plan with limited amount of notifications that you can receive on WhatsApp.</p>
            <p>Please consider becoming VIP to increase your limits, receive WhatsApp notifications in a group and have additional premium features.</p>  
        </div>

        <div style="margin-top: 30px; background-color: #f8f9fa; padding: 15px; border: 1px solid #ddd;">
            <h2>Plugin Information</h2>
            <p><strong>Version:</strong> 1.1.2</p>
            <p><strong>Requirements:</strong> WordPress 5.0+ and PHP 7.0+</p>
            <p><strong>Support:</strong> For support, please visit <a href="https://beepmate.io" target="_blank">https://beepmate.io</a> or contact <a href="mailto:help@beepmate.io">help@beepmate.io</a></p>
        </div>
    </div>
    <?php
}

/**
 * Handle test message submission
 */
function beepmate_whatsapp_forms_handle_test_message() {
    if (!isset($_POST['action']) || $_POST['action'] !== 'send_test_message') {
        return;
    }
    
    if (!isset($_POST['beepmate_whatsapp_forms_test_nonce']) || !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['beepmate_whatsapp_forms_test_nonce'])), 'beepmate_whatsapp_forms_test')) {
        wp_die('Security check failed');
    }
    
    if (!current_user_can('manage_options')) {
        wp_die('You do not have sufficient permissions');
    }
    
    $test_message = isset($_POST['test_message']) ? sanitize_text_field(wp_unslash($_POST['test_message'])) : '';
    if (empty($test_message)) {
        add_settings_error('beepmate_whatsapp_forms', 'empty_message', 'Please enter a test message', 'error');
        return;
    }
    
    $options = get_option('beepmate_whatsapp_forms_settings');
    
    if (empty($options['beepmate_api_key'])) {
        add_settings_error('beepmate_whatsapp_forms', 'missing_api_key', 'BeepMate API key is required', 'error');
        return;
    }
    
    if (empty($options['whatsapp_recipient_id'])) {
        add_settings_error('beepmate_whatsapp_forms', 'missing_recipient', 'WhatsApp ID is required', 'error');
        return;
    }
    
    // Send API call
    $result = beepmate_whatsapp_forms_send_to_beepmate($options['beepmate_api_key'], $options['whatsapp_recipient_id'], $test_message);
    
    if ($result === true) {
        add_settings_error('beepmate_whatsapp_forms', 'send_success', 'Test message sent successfully! Check your WhatsApp to confirm.', 'success');
    } else {
        add_settings_error('beepmate_whatsapp_forms', 'send_error', 'Failed to send test message: ' . $result, 'error');
    }
}
add_action('admin_init', 'beepmate_whatsapp_forms_handle_test_message');

/**
 * Sanitize and prepare message text
 * 
 * @param string $message The message to sanitize
 * @return string The sanitized message
 */
function beepmate_whatsapp_forms_prepare_message($message) {
// Replace HTML entities with their actual characters
    $message = html_entity_decode($message, ENT_QUOTES | ENT_HTML5, 'UTF-8');
    
    // First, temporarily replace email patterns to protect them
    $pattern = '/([a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,})/';
    preg_match_all($pattern, $message, $matches);
    
    // Create unique placeholders for each email
    $emails = $matches[0];
    $placeholders = [];
    foreach ($emails as $index => $email) {
        $placeholder = "##EMAIL_PLACEHOLDER_{$index}##";
        $placeholders[$placeholder] = $email;
        $message = str_replace($email, $placeholder, $message);
    }
    
    // Replace angle brackets with fullwidth versions
    // but preserve email format like "From: Name <email@example.com>"
    $search = array('<', '>');
    $replace = array('＜', '＞'); // Using fullwidth versions
    $message = str_replace($search, $replace, $message);
    
    // Now restore the emails using the placeholders
    foreach ($placeholders as $placeholder => $email) {
        $message = str_replace($placeholder, $email, $message);
    }
    
    // Handle ampersand separately
    $message = str_replace('&', '＆', $message);
    
    // Remove control characters except for newlines and tabs
    $message = preg_replace('/[\x00-\x08\x0B-\x0C\x0E-\x1F\x7F]/', '', $message);
    
    return $message;
}

/**
 * Send message to BeepMate API using the configured method
 *
 * @param string $api_key The BeepMate API key
 * @param string $recipient_id The WhatsApp recipient ID
 * @param string $message The message to send
 * @return true|string True on success, error message on failure
 */
function beepmate_whatsapp_forms_send_to_beepmate($api_key, $recipient_id, $message) {
    $options = get_option('beepmate_whatsapp_forms_settings');
    $api_method = $options['api_method'] ?? 'wp_remote';
    
    // Prepare the message text
    $prepared_message = beepmate_whatsapp_forms_prepare_message($message);
    
    // URL encode the prepared message
    $encoded_message = urlencode($prepared_message);
    
    // BeepMate API URL with URL-encoded parameters
    $api_url = "https://beepmate.io/send?key={$api_key}&id={$recipient_id}&msg={$encoded_message}";
    
    // Log the attempt
    beepmate_whatsapp_forms_debug('Making API call using method: ' . $api_method);
    beepmate_whatsapp_forms_debug('Original message: ' . $message);
    beepmate_whatsapp_forms_debug('Prepared message: ' . $prepared_message);
    
    // Choose the appropriate method
    switch ($api_method) {
        case 'file_get_contents':
            return beepmate_whatsapp_forms_file_get_contents_call($api_url);
            
        case 'exec':
            return beepmate_whatsapp_forms_exec_call($api_key, $recipient_id, $encoded_message);
            
        case 'curl':
            return beepmate_whatsapp_forms_curl_call($api_url);
            
        case 'wp_remote':
        default:
            return beepmate_whatsapp_forms_wp_remote_call($api_url);
    }
}

/**
 * Make API call using file_get_contents
 */
function beepmate_whatsapp_forms_file_get_contents_call($api_url) {
    // Create stream context with timeout
    $opts = [
        'http' => [
            'timeout' => 30,
            'ignore_errors' => true
        ]
    ];
    $context = stream_context_create($opts);
    
    // Log the URL (without API key)
    $log_url = preg_replace('/key=([^&]+)/', 'key=HIDDEN', $api_url);
    beepmate_whatsapp_forms_debug('file_get_contents API URL: ' . $log_url);
    
    // Make the API call
    $response = @file_get_contents($api_url, false, $context);
    
    // Get HTTP response code
    $status_line = $http_response_header[0] ?? '';
    preg_match('{HTTP\/\S*\s(\d{3})}', $status_line, $matches);
    $http_code = $matches[1] ?? 'unknown';
    
    // Log the response
    beepmate_whatsapp_forms_debug('file_get_contents HTTP Status: ' . $http_code);
    beepmate_whatsapp_forms_debug('file_get_contents Response: ' . $response);
    
    // Check response
    if ($response !== false && $http_code == 200) {
        return true;
    } else {
        return 'HTTP error: ' . $http_code;
    }
}

/**
 * Make API call using cURL
 */
function beepmate_whatsapp_forms_curl_call($api_url) {
    // Check if cURL is available
    if (!function_exists('curl_init')) {
        beepmate_whatsapp_forms_debug('cURL is not available');
        return 'cURL is not available on this server';
    }
    
    // Log the URL (without API key)
    $log_url = preg_replace('/key=([^&]+)/', 'key=HIDDEN', $api_url);
    beepmate_whatsapp_forms_debug('cURL API URL: ' . $log_url);
    
    // Initialize cURL
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $api_url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 30);
    curl_setopt($ch, CURLOPT_TIMEOUT, 30);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
    
    // Execute cURL request
    $response = curl_exec($ch);
    $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    $curl_error = curl_error($ch);
    curl_close($ch);
    
    // Log the response
    beepmate_whatsapp_forms_debug('cURL HTTP Status: ' . $http_code);
    beepmate_whatsapp_forms_debug('cURL Response: ' . $response);
    if (!empty($curl_error)) {
        beepmate_whatsapp_forms_debug('cURL Error: ' . $curl_error);
    }
    
    // Check response
    if ($http_code == 200) {
        return true;
    } else {
        return 'cURL error: ' . ($curl_error ?: 'HTTP status ' . $http_code);
    }
}

/**
 * Make API call using exec
 * 
 * Note: The message should already be URL-encoded before calling this function
 */
function beepmate_whatsapp_forms_exec_call($api_key, $recipient_id, $encoded_message) {
    if (!function_exists('exec')) {
        beepmate_whatsapp_forms_debug('exec() is not available');
        return 'exec() is not available on this server';
    }
    
    // For the exec method, we don't use shell escaping for the message
    // Instead, we use the already URL-encoded message
    $api_url = "https://beepmate.io/send?key=" . urlencode($api_key) . "&id=" . urlencode($recipient_id) . "&msg=" . $encoded_message;
    
    // Log the URL (without API key)
    $log_url = preg_replace('/key=([^&]+)/', 'key=HIDDEN', $api_url);
    beepmate_whatsapp_forms_debug('exec API URL: ' . $log_url);
    
    // Execute the curl command
    $cmd = "curl -k -s -S \"$api_url\"";
    beepmate_whatsapp_forms_debug('Command (partial): curl -k -s -S "[URL with API key hidden]"');
    
    @exec($cmd . ' 2>&1', $output, $return_var);
    
    // Log result
    beepmate_whatsapp_forms_debug('exec() return code: ' . $return_var);
    if (!empty($output)) {
        beepmate_whatsapp_forms_debug('exec() output: ' . implode("\n", $output));
    }
    
    // Check result
    if ($return_var === 0) {
        return true;
    } else {
        return 'Command execution error: ' . $return_var;
    }
}

// Handle consecutive whitespace in emails
function beepmate_whatsapp_forms_clean_whitespace($text) {
    // First normalize all line breaks to \n
    $text = str_replace(["\r\n", "\r"], "\n", $text);
    
    // Remove leading/trailing whitespace from each line
    $lines = explode("\n", $text);
    $lines = array_map('trim', $lines);
    $text = implode("\n", $lines);
    
    // Convert tabs to spaces to simplify handling
    $text = str_replace("\t", "  ", $text);
    
    // Handle consecutive spaces - replace 3+ spaces with just 2
    while (strpos($text, '   ') !== false) {
        $text = str_replace('   ', '  ', $text);
    }
    
    // Handle consecutive newlines - replace 3+ with just 2
    while (strpos($text, "\n\n") !== false) {
        $text = str_replace("\n\n", "\n", $text);
    }
    
    // Clean up any whitespace-only lines
    $lines = explode("\n", $text);
    $clean_lines = [];
    
    foreach ($lines as $line) {
        // Skip lines that are just whitespace
        if (trim($line) === '') {
            $clean_lines[] = '';  // Add a completely empty line
        } else {
            $clean_lines[] = $line;
        }
    }
    
    $text = implode("\n", $clean_lines);
    
    // Final pass to remove any remaining 3+ consecutive newlines
    while (strpos($text, "\n\n") !== false) {
        $text = str_replace("\n\n", "\n\n", $text);
    }
    
    return $text;
}

/**
 * Intercept PHPMailer
 */
function beepmate_whatsapp_forms_phpmailer_init($phpmailer) {
    $options = get_option('beepmate_whatsapp_forms_settings');
    $redirect_all = $options['redirect_all_forms'] ?? 'no';
    
    // Only proceed if we want to redirect all forms
    if ($redirect_all !== 'yes') {
		beepmate_whatsapp_forms_debug('BeepMate plugin disabled.');
        return;
    }
	
	beepmate_whatsapp_forms_debug('phpmailer: ' . print_r($phpmailer,1));
	beepmate_whatsapp_forms_debug('Mailer options: ' . print_r($options,1));
	    
    // Get email components
    $to_addresses = $phpmailer->getToAddresses();
    $to = '';
    foreach ($to_addresses as $address) {
        $to .= isset($address[1]) ? $address[1] . ' <' . $address[0] . '>' : $address[0];
        $to .= ', ';
    }
    $to = rtrim($to, ', ');
    
    $subject = $phpmailer->Subject;
    $body = '';
    
    // Get the appropriate body content
    if (!empty($phpmailer->AltBody)) {
        // Prefer plain text version if available
        $body = $phpmailer->AltBody;
    } else if (!empty($phpmailer->Body)) {
        $html_body = $phpmailer->Body;
        
        // Remove style tags and their content completely
        $html_body = preg_replace('/<style\b[^>]*>(.*?)<\/style>/is', '', $html_body);
        
        // Find and preserve file attachment links
        $link_pattern = '/<a\s+href=[\'"]([^\'"]+)[\'"][^>]*>([^<]+)<\/a>/i';
        preg_match_all($link_pattern, $html_body, $matches, PREG_SET_ORDER);
        
        $link_placeholders = [];
        foreach ($matches as $index => $match) {
            // Only preserve links that appear to be file attachments (have filename extension)
            $url = $match[1];
            $text = $match[2];
            
            // Check if this looks like a file attachment
            if (preg_match('/\.(pdf|docx?|xlsx?|png|jpe?g|gif|zip|rar|txt)($|\?)/i', $url)) {
                $placeholder = "##LINK_PLACEHOLDER_{$index}##";
                $link_placeholders[$placeholder] = "$text ($url)";
                $html_body = str_replace($match[0], $placeholder, $html_body);
            }
        }
        
        // Convert <br>, <p>, <div> tags to newlines
        $html_body = preg_replace('/<br\s*\/?>/i', "\n", $html_body);
        $html_body = preg_replace('/<\/p>\s*<p[^>]*>/i', "\n\n", $html_body);
        $html_body = preg_replace('/<\/div>\s*<div[^>]*>/i', "\n", $html_body);
        $html_body = preg_replace('/<p[^>]*>/i', "", $html_body);
        $html_body = preg_replace('/<\/p>/i', "\n\n", $html_body);
        $html_body = preg_replace('/<div[^>]*>/i', "", $html_body);
        $html_body = preg_replace('/<\/div>/i', "\n", $html_body);
        
        // Replace email patterns with placeholders to protect them
        $email_pattern = '/([^<]*<[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}>)/';
        preg_match_all($email_pattern, $html_body, $matches);
        
        // Create placeholders
        $email_sections = $matches[0] ?? [];
        $placeholders = [];
        foreach ($email_sections as $index => $section) {
            $placeholder = "##EMAIL_SECTION_{$index}##";
            $placeholders[$placeholder] = $section;
            $html_body = str_replace($section, $placeholder, $html_body);
        }
        
        // Strip HTML tags
        $body = wp_strip_all_tags($html_body);
        
        // Restore email patterns
        foreach ($placeholders as $placeholder => $original) {
            $body = str_replace($placeholder, $original, $body);
        }
		
		// Restore file attachment links
        foreach ($link_placeholders as $placeholder => $link_text) {
            $body = str_replace($placeholder, $link_text, $body);
        }
    }
	$body = beepmate_whatsapp_forms_clean_whitespace($body);
    
    // Format message for WhatsApp 
    $whatsapp_message = "New Form Submission\n\n";
    $whatsapp_message .= "Subject: $subject\n";
    $whatsapp_message .= "To: $to\n\n";
    $whatsapp_message .= "Message:\n$body";
    
    // Send to WhatsApp
    $api_key = $options['beepmate_api_key'] ?? '';
    $recipient_id = $options['whatsapp_recipient_id'] ?? '';
    
    $result = beepmate_whatsapp_forms_send_to_beepmate($api_key, $recipient_id, $whatsapp_message);
    
    // Log result
    if ($result === true) {
        beepmate_whatsapp_forms_debug('Successfully sent email content to WhatsApp');
    } else {
        beepmate_whatsapp_forms_debug('Failed to send to WhatsApp: ' . $result);
    }
}
add_action('phpmailer_init', 'beepmate_whatsapp_forms_phpmailer_init');

/**
 * Add settings link on plugin page
 */
function beepmate_whatsapp_forms_settings_link($links) {
    $settings_link = '<a href="options-general.php?page=beepmate">Settings</a>';
    array_unshift($links, $settings_link);
    return $links;
}
$plugin_basename = plugin_basename(__FILE__);
add_filter("plugin_action_links_$plugin_basename", 'beepmate_whatsapp_forms_settings_link');

?>
